# プロジェクト名

このファイルは、SlackSDKにおける基本操作をより使いやすいようにインスタンスにまとめて管理できるようにまとめたものになっています。
初心者の方でも間違いを少なく、チャンネルの作成からユーザーの招待、投稿の送信などを行うことができます。
意識していることは、INIADのチーム開発で同様のSlackBotを作成されたいという有志の方に向けてです。
個別の使用方法を教授することはありません。

## ライセンス

このプロジェクトはMITライセンスの下で提供されています。詳細は[LICENSE](./LICENSE)ファイルを参照してください。

## 使用しているライブラリ

このプロジェクトでは以下のライブラリを使用しています：

- [slack-sdk](https://github.com/slackapi/python-slack-sdk) - MIT License
